@@ -1,15 +1,17 @@
 """
-Utilities for creating NeXus format files.
+General tools useful to create NeXus format files.
 """
 
 __author__ = "Diamond Light Source - Scientific Software"
 __email__ = "scientificsoftware@diamond.ac.uk"
-__version__ = "0.4.16"
+__version__ = "0.5.0"
 __version_tuple__ = tuple(int(x) for x in __version__.split("."))
 
+import sys
 import numpy as np
 
 from h5py import AttributeManager
+from pathlib import Path
 
 
 def imgcif2mcstas(vector):
@@ -66,3 +68,25 @@ def set_dependency(dep_info, path=None):
         return np.string_(path + dep_info)
     else:
         return np.string_(dep_info)
+
+
+def get_filename_template(master_filename: Path) -> str:
+    """
+    Get the data file name template from the master file.
+
+    Args:
+        master_filename:    Path object containing the name of master file.
+                            The format should be either file_master.h5 or file.nxs.
+    Returns:
+        filename_template:  String template for the name of blank data file.
+    """
+    if master_filename.suffix == ".nxs":
+        filename_root = master_filename.stem
+        filename_template = master_filename.parent / f"{filename_root}_%0{6}d.h5"
+    elif master_filename.suffix == ".h5":
+        filename = master_filename.stem.replace("master", f"%0{6}d")
+        filename_template = master_filename.parent / f"{filename}.h5"
+    else:
+        sys.exit("Master file did not have the expected format.")
+    # so that filename_template.as_posix() % 1 will become filename_000001.h5
+    return filename_template.as_posix()
